@@ -744,13 +744,17 @@ class Tree(list):
 
         print(TreePrettyPrinter(self, sentence, highlight).text(**kwargs), file=stream)
 
+    def to_list(self):
+        return [self.label(), [t.to_list() if isinstance(t, Tree) else t for t in self]]
+
+    @staticmethod
+    def from_list(L):
+        if isinstance(L, str):
+            return L
+        return Tree(L[0], [Tree.from_list(child) for child in L[1]])
+
     def __repr__(self):
-        childstr = ", ".join(repr(c) for c in self)
-        return '%s(%s, [%s])' % (
-            type(self).__name__,
-            self._label,
-            childstr,
-        )
+        return repr(self.to_list())
 
     def __str__(self):
         return self.pformat()
@@ -1553,6 +1557,7 @@ def demo():
     print("Convert bracketed string into tree:")
     print(t)
     print(t.__repr__())
+    print(Tree.from_list(['S', [['NP', [['DT', ['the']], ['NN', ['cat']]]], ['VP', [['VBD', ['ate']], ['NP', [['DT', ['a']], ['NN', ['cookie']]]]]]]]))
 
     print("Display tree properties:")
     print(t.label())  # tree's constituent type
